/*
  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-only
*/

#pragma once

#include <QObject>

class FilterImporterAkonadiTest : public QObject
{
    Q_OBJECT
public:
    explicit FilterImporterAkonadiTest(QObject *parent = nullptr);
    ~FilterImporterAkonadiTest() = default;
};

